<?php
/**
 * User: nester_a
 * Date: 15.07.14
 */

namespace Webex\Repository\Remote;

use LMS\Libraries\Http;
use LMS\Libraries\Date;
use LMS\Libraries\Exception;

class Booking
{

	/**
	 * @var Http\Request
	 */
	private $httpRequest;

	/**
	 * @var Date\Handler
	 */
	private $dateHandler;

	public function __construct($options)
	{
		$this->httpRequest = new Http\Request();
		$this->dateHandler = new Date\Handler();
	}

	/**
	 * @param $teacherID
	 * @param $fromTime
	 * @param $toTime
	 * @param $cPublic
	 * @param $pName
	 * @param $pDescription
	 * @return mixed
	 */
	public function save($params)
	{
		$date = new \DateTime();
		$params['duration'] = ($params['to_time'] - $params['from_time']) / 60;
		$params['timezoneID'] = $date->getOffset() / 3600;
		$params['start_date'] = date("m/d/Y H:i:s", $params['from_time']);
		$params['meetingPassword'] = substr(sha1(time()), 2, 7);

		$schema = $this->httpRequest->loadXMLSchema(__DIR__ . '/../../schemas/meeting/create.xml.phtml', $params);
		$response = $this->httpRequest->sendJSONRequest('https://apidemoeu.webex.com/WBXService/XMLService', $schema, 'POST',  array('Content-Type: text/xml'));

		$meetingData = new \SimpleXMLElement($response);
		$result = $meetingData->xpath('//serv:result');
		if($result[0] != 'SUCCESS'){
			throw new Exception\Operation\Error(
				'WebEX API Error: ' . $meetingData->xpath('//serv:reason')[0],
				sefRelToAbs('index.php?option=com_joomla_lms&task=conference.booking&id='.$params['courseID']));
		}

		$meeting = new \stdClass();
		$meeting->meeting_id = $meetingData->xpath('//meet:meetingkey')[0];
		$meeting->unique_meeting_id = $meetingData->xpath('//meet:meetingkey')[0];
		$meeting->join_url = $meetingData->xpath('//serv:attendee')[0];
		$meeting->password = $params['meetingPassword'];

		return $meeting;
	}

	/**
	 * @param $bookedConferenceIDs
	 * @return mixed
	 */
	public function delete($meetingId)
	{
		$url = 'https://api.citrixonline.com/G2M/rest/meetings/'.$meetingId;
		$response = $this->httpRequest->sendJSONRequest($url, array(), 'DELETE', $this->httpRequest->getHeadersForGTM($this->oauthData->token));
		return $response === false ? false : true;
	}

	/**
	 * @param $meetingID
	 * @return mixed
	 */
	public function update($meeting, $params)
	{
		$params = array_merge($params, $this->prepareTimeToGTMFormat($params));
		$data = $this->prepareDataRemoteService($params);

		$url = 'https://api.citrixonline.com/G2M/rest/meetings/'.$meeting->meeting_id;
		return $this->httpRequest->sendJSONRequest($url, json_encode($data), 'PUT', $this->httpRequest->getHeadersForGTM($this->oauthData->token));
	}

	/**
	 * @param $params
	 * @return array
	 */
	protected function prepareDataRemoteService($params)
	{
		return array(
			'subject' => $params['p_name'],
			'starttime' =>  $params['fromTime'],
			'endtime' => $params['toTime'],
			'passwordrequired' => (string)($params['c_public'] == 0),
			'conferencecallinfo' => $params['p_description'],
			'timezonekey' => "",
			'meetingtype' => 'Scheduled'
		);

	}


}