<?php
/**
 * User: nester_a
 * Date: 01.07.14
 */

namespace Gtm\Repository\Remote;

use LMS\Libraries\Http;
use LMS\Libraries\Date;

class Booking
{

	/**
	 * @var Http\Request
	 */
	private $httpRequest;

	private $oauthData;

	/**
	 * @var Date\Handler
	 */
	private $dateHandler;

	public function __construct($options)
	{
		$this->oauthData = $options['oauthData'];
		$this->httpRequest = new Http\Request();
		$this->dateHandler = new Date\Handler();
	}

	/**
	 * @param $teacherID
	 * @param $fromTime
	 * @param $toTime
	 * @param $cPublic
	 * @param $pName
	 * @param $pDescription
	 * @return mixed
	 */
	public function save($params)
	{
		$params = array_merge($params, $this->prepareTimeToGTMFormat($params));
		$data = $this->prepareDataRemoteService($params);

		$url = 'https://api.citrixonline.com/G2M/rest/meetings';
		$response = $this->httpRequest->sendJSONRequest($url, json_encode($data), 'POST', $this->httpRequest->getHeadersForGTM($this->oauthData->token));

		$meetingData = json_decode($response);
		return $meetingData;
	}

	/**
	 * @param $bookedConferenceIDs
	 * @return mixed
	 */
	public function delete($meetingId)
	{
		$url = 'https://api.citrixonline.com/G2M/rest/meetings/'.$meetingId;
		$response = $this->httpRequest->sendJSONRequest($url, array(), 'DELETE', $this->httpRequest->getHeadersForGTM($this->oauthData->token));
		return $response === false ? false : true;
	}

	/**
	 * @param $meetingID
	 * @return mixed
	 */
	public function update($meeting, $params)
	{
		$params = array_merge($params, $this->prepareTimeToGTMFormat($params));
		$data = $this->prepareDataRemoteService($params);

		$url = 'https://api.citrixonline.com/G2M/rest/meetings/'.$meeting->meeting_id;
		return $this->httpRequest->sendJSONRequest($url, json_encode($data), 'PUT', $this->httpRequest->getHeadersForGTM($this->oauthData->token));
	}

	/**
	 * @return bool|mixed
	 */
	public function get()
	{
		$url = 'https://api.citrixonline.com/G2M/rest/meetings';
		$response = $this->httpRequest->sendJSONRequest($url, array(), 'GET', $this->httpRequest->getHeadersForGTM($this->oauthData->token));

		$meetings = json_decode($response);
		if($meetings === false){
			return false;
		}
		return $meetings;
	}

	/**
	 * @param $params
	 * @return array
	 */
	protected function prepareDataRemoteService($params)
	{
		return array(
			'subject' => $params['p_name'],
			'starttime' =>  $params['fromTime'],
			'endtime' => $params['toTime'],
			'passwordrequired' => (string)($params['public'] == 0),
			'conferencecallinfo' => strip_tags($params['p_description']),
			'timezonekey' => "",
			'meetingtype' => 'Scheduled'
		);

	}


	protected function prepareTimeToGTMFormat($params)
	{
		$times = array();

		$times['fromTime'] = $this->dateHandler->getUTCDatetime('Y-m-d\TH:i:s', $params['from_time']);
		$times['toTime'] = $this->dateHandler->getUTCDatetime('Y-m-d\TH:i:s', $params['to_time']);

		return $times;
	}
}